@@ -54,7 +54,7 @@ var searchData=
   ['templateidentifier',['TemplateIdentifier',['../structcom_1_1sun_1_1star_1_1configuration_1_1backend_1_1TemplateIdentifier.html',1,'com::sun::star::configuration::backend']]],
   ['templatename',['TemplateName',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1TemplateName.html',1,'com::sun::star::text::textfield']]],
   ['terminationvetoexception',['TerminationVetoException',['../exceptioncom_1_1sun_1_1star_1_1frame_1_1TerminationVetoException.html',1,'com::sun::star::frame']]],
-  ['text',['Text',['../servicecom_1_1sun_1_1star_1_1text_1_1Text.html',1,'Text'],['../servicecom_1_1sun_1_1star_1_1drawing_1_1Text.html',1,'Text']]],
+  ['text',['Text',['../servicecom_1_1sun_1_1star_1_1drawing_1_1Text.html',1,'Text'],['../servicecom_1_1sun_1_1star_1_1text_1_1Text.html',1,'Text']]],
   ['textcolumn',['TextColumn',['../structcom_1_1sun_1_1star_1_1text_1_1TextColumn.html',1,'com::sun::star::text']]],
   ['textcolumns',['TextColumns',['../servicecom_1_1sun_1_1star_1_1text_1_1TextColumns.html',1,'com::sun::star::text']]],
   ['textconnectionsettings',['TextConnectionSettings',['../servicecom_1_1sun_1_1star_1_1sdb_1_1TextConnectionSettings.html',1,'com::sun::star::sdb']]],
@@ -68,7 +68,7 @@ var searchData=
   ['textembeddedobject',['TextEmbeddedObject',['../servicecom_1_1sun_1_1star_1_1text_1_1TextEmbeddedObject.html',1,'com::sun::star::text']]],
   ['textembeddedobjects',['TextEmbeddedObjects',['../servicecom_1_1sun_1_1star_1_1text_1_1TextEmbeddedObjects.html',1,'com::sun::star::text']]],
   ['textevent',['TextEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1TextEvent.html',1,'com::sun::star::awt']]],
-  ['textfield',['TextField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1TextField.html',1,'TextField'],['../servicecom_1_1sun_1_1star_1_1text_1_1TextField.html',1,'TextField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1TextField.html',1,'TextField']]],
+  ['textfield',['TextField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1TextField.html',1,'TextField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1TextField.html',1,'TextField'],['../servicecom_1_1sun_1_1star_1_1text_1_1TextField.html',1,'TextField']]],
   ['textfieldenumeration',['TextFieldEnumeration',['../servicecom_1_1sun_1_1star_1_1text_1_1TextFieldEnumeration.html',1,'com::sun::star::text']]],
   ['textfieldmaster',['TextFieldMaster',['../servicecom_1_1sun_1_1star_1_1text_1_1TextFieldMaster.html',1,'com::sun::star::text']]],
   ['textfieldmasters',['TextFieldMasters',['../servicecom_1_1sun_1_1star_1_1text_1_1TextFieldMasters.html',1,'com::sun::star::text']]],
@@ -131,7 +131,7 @@ var searchData=
   ['theuielementfactorymanager',['theUIElementFactoryManager',['../singletoncom_1_1sun_1_1star_1_1ui_1_1theUIElementFactoryManager.html',1,'com::sun::star::ui']]],
   ['thewindowcontentfactorymanager',['theWindowContentFactoryManager',['../singletoncom_1_1sun_1_1star_1_1ui_1_1theWindowContentFactoryManager.html',1,'com::sun::star::ui']]],
   ['thewindowstateconfiguration',['theWindowStateConfiguration',['../singletoncom_1_1sun_1_1star_1_1ui_1_1theWindowStateConfiguration.html',1,'com::sun::star::ui']]],
-  ['time',['Time',['../servicecom_1_1sun_1_1star_1_1xsd_1_1Time.html',1,'Time'],['../structcom_1_1sun_1_1star_1_1util_1_1Time.html',1,'Time']]],
+  ['time',['Time',['../structcom_1_1sun_1_1star_1_1util_1_1Time.html',1,'Time'],['../servicecom_1_1sun_1_1star_1_1xsd_1_1Time.html',1,'Time']]],
   ['timefield',['TimeField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1TimeField.html',1,'TimeField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1TimeField.html',1,'TimeField']]],
   ['timefilterpair',['TimeFilterPair',['../structcom_1_1sun_1_1star_1_1animations_1_1TimeFilterPair.html',1,'com::sun::star::animations']]],
   ['timeincrement',['TimeIncrement',['../structcom_1_1sun_1_1star_1_1chart_1_1TimeIncrement.html',1,'com::sun::star::chart']]],
